@@ -1,4 +1,4 @@
-package Pcore::DBD v0.2.0;
+package Pcore::DBD v0.3.0;
 
 use Pcore qw[-role];
 use DBI;
@@ -109,7 +109,7 @@ sub selectall_hashref {
 
     my $res = $self->h->selectall_hashref( ref $query ? $args{nocache} ? $query->sql : $query->sth : $query, \@key_cols, $args{attr}, $args{bind} ? $args{bind}->@* : ref $query ? $query->bind->@* : () );
 
-    if ( keys $res ) {
+    if ( keys $res->%* ) {
         return $res;
     }
     else {
@@ -209,7 +209,7 @@ sub selectval {
 # TODO sth caching not supported for multiple queries
 # add workaround for queries, that contains multiply queries
 # see DBD::SQLite do implementation
-sub do {    ## no critic qw(Subroutines::ProhibitBuiltinHomonyms)
+sub do {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
     my $self  = shift;
     my $query = shift;
     my %args  = (
@@ -346,6 +346,8 @@ sub ddl {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
+## │    3 │ 112                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
 ## │    3 │ 235                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_default_attr' declared but not     │
 ## │      │                      │ used                                                                                                           │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
